@@ -675,6 +675,11 @@ class PullRequest(OgrAbstractClass):
         """Web URL to the list of commits in the pull request."""
         raise NotImplementedError()
 
+    @property
+    def closed_by(self) -> Optional[str]:
+        """Login of the account that closed the pull request."""
+        raise NotImplementedError
+
     def __str__(self) -> str:
         description = (
             f"{self.description[:10]}..." if self.description is not None else "None"
@@ -1744,6 +1749,18 @@ class GitProject(OgrAbstractClass):
         """
         raise NotImplementedError()
 
+    def get_commit_comments(self, commit: str) -> List[CommitComment]:
+        """
+        Get comments for a commit.
+
+        Args:
+            commit: The hash of the commit.
+
+        Returns:
+            List of all comments for the commit.
+        """
+        raise NotImplementedError()
+
     def set_commit_status(
         self,
         commit: str,
