@@ -1,24 +1,5 @@
-# MIT License
-#
-# Copyright (c) 2018-2019 Red Hat, Inc.
-
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+# Copyright Contributors to the Packit project.
+# SPDX-License-Identifier: MIT
 
 import functools
 from typing import Dict, Type, Optional, Set, Iterable
@@ -38,20 +19,25 @@ def use_for_service(service: str, _func=None):
     this implementation will be used to initialize the project.
 
     When using this decorator, be sure that your class is initialized.
-    (Add the import to ogr/__init__.py )
+    (Add the import to `ogr/__init__.py`)
 
     Usage:
+    ```py
+    @use_for_service("github.com")
+    class GithubService(BaseGitService):
+        pass
 
-        @use_for_service("github.com")
-        class GithubService(BaseGitService):
-            pass
+    @use_for_service("pagure.io")
+    @use_for_service("src.fedoraproject.org")
+    class PagureService(BaseGitService):
+        pass
+    ```
 
-        @use_for_service("pagure.io")
-        @use_for_service("src.fedoraproject.org")
-        class PagureService(BaseGitService):
-            pass
+    Args:
+        service: URL of the service.
 
-    :param service: str (url of the service)
+    Returns:
+        Decorator.
     """
 
     def decorator_cover(func):
@@ -73,15 +59,27 @@ def get_project(
     **kwargs,
 ) -> GitProject:
     """
-    Return the project for the given url.
+    Return the project for the given URL.
 
-    :param url: str (url of the project, e.g. "https://github.com/packit/ogr")
-    :param service_mapping_update: custom mapping from  service url (str) to service class
-    :param custom_instances: list of instances that will be used when creating a project instance
-    :param force_custom_instance: force picking a Git service from the custom_instances list,
-        if there is any provided, raise an error if that's not possible
-    :param kwargs: arguments forwarded to __init__ of the matching service
-    :return: GitProject using the matching implementation
+    Args:
+        url: URL of the project, e.g. `"https://github.com/packit/ogr"`.
+        service_mapping_update: Custom mapping from
+            service url (`str`) to service class.
+
+            Defaults to no mapping.
+        custom_instances: List of instances that will be
+            used when creating a project instance.
+
+            Defaults to `None`.
+        force_custom_instance: Force picking a Git service from the
+            `custom_instances` list, if there is any provided, raise an error if
+            that is not possible.
+
+            Defaults to `True`.
+        **kwargs: Arguments forwarded to __init__ of the matching service.
+
+    Returns:
+        `GitProject` using the matching implementation.
     """
     mapping = service_mapping_update.copy() if service_mapping_update else {}
     custom_instances = custom_instances or []
@@ -115,19 +113,26 @@ def get_service_class_or_none(
     url: str, service_mapping_update: Dict[str, Type[GitService]] = None
 ) -> Optional[Type[GitService]]:
     """
-    Get the matching service class from the url.
+    Get the matching service class from the URL.
 
-    :param url: str (url of the project, e.g. "https://github.com/packit/ogr")
-    :param service_mapping_update: custom mapping from  service url (str) to service class
-    :return: Matched class (subclass of GitService) or None
+    Args:
+        url: URL of the project, e.g. `"https://github.com/packit/ogr"`.
+        service_mapping_update: Custom mapping from service url (`str`) to service
+            class.
+
+            Defaults to `None`.
+
+    Returns:
+        Matched class (subclass of `GitService`) or `None`.
     """
     mapping = {}
     mapping.update(_SERVICE_MAPPING)
     if service_mapping_update:
         mapping.update(service_mapping_update)
 
+    parsed_url = parse_git_repo(url)
     for service, service_kls in mapping.items():
-        if service in url:
+        if service in parsed_url.hostname:
             return service_kls
 
     return None
@@ -137,11 +142,17 @@ def get_service_class(
     url: str, service_mapping_update: Dict[str, Type[GitService]] = None
 ) -> Type[GitService]:
     """
-    Get the matching service class from the url.
+    Get the matching service class from the URL.
 
-    :param url: str (url of the project, e.g. "https://github.com/packit/ogr")
-    :param service_mapping_update: custom mapping from  service url (str) to service class
-    :return: Matched class (subclass of GitService)
+    Args:
+        url: URL of the project, e.g. `"https://github.com/packit/ogr"`.
+        service_mapping_update: Custom mapping from service url (str) to service
+            class.
+
+            Defaults to `None`.
+
+    Returns:
+        Matched class (subclass of `GitService`).
     """
     service_kls = get_service_class_or_none(
         url=url, service_mapping_update=service_mapping_update
@@ -151,43 +162,49 @@ def get_service_class(
     raise OgrException("No matching service was found.")
 
 
-def get_instances_from_dict(instances: dict) -> Set[GitService]:
+def get_instances_from_dict(instances: Dict) -> Set[GitService]:
     """
     Load the service instances from the dictionary in the following form:
 
-    key = hostname, url or name that can be mapped to the service-type
-    value = dictionary with arguments used when creating a new instance of the service
-            (passed to the `__init__` method)
+    - `key`   : hostname, url or name that can be mapped to the service-type
+    - `value` : dictionary with arguments used when creating a new instance of the
+    service (passed to the `__init__` method)
 
     e.g.:
-
-    {
+    ```py
+    get_instances_from_dict({
         "github.com": {"token": "abcd"},
         "pagure": {
             "token": "abcd",
             "instance_url": "https://src.fedoraproject.org",
         },
-    },
-    => {
-    GithubService(token="abcd"),
-    PagureService(token="abcd", instance_url="https://src.fedoraproject.org")
+    }) == {
+        GithubService(token="abcd"),
+        PagureService(token="abcd", instance_url="https://src.fedoraproject.org")
     }
+    ```
 
-    When the mapping key->service-type is not recognised, you can add a `type` key to the dictionary
-    and specify the type of the instance.
-    (It can be either name, hostname or url. The used mapping is same as for key->service-type.)
+    When the mapping `key->service-type` is not recognised, you can add a `type`
+    key to the dictionary and specify the type of the instance.
+    (It can be either name, hostname or url. The used mapping is same as for
+    key->service-type.)
 
-    The provided `key` is used as an `instance_url` and passed to the `__init__` method as well.
+    The provided `key` is used as an `instance_url` and passed to the `__init__`
+    method as well.
 
     e.g.:
-
-    {
+    ```py
+    get_instances_from_dict({
         "https://my.gtlb": {"token": "abcd", "type": "gitlab"},
-    },
-    => {GitlabService(token="abcd", instance_url="https://my.gtlb")}
+    }) == {GitlabService(token="abcd", instance_url="https://my.gtlb")}
+    ```
 
-    :param instances: mapping from service name/url/hostname to attributes for the service creation
-    :return: set of the service instances
+    Args:
+        instances: Mapping from service name/url/hostname to attributes for the
+            service creation.
+
+    Returns:
+        Set of the service instances.
     """
     services = set()
     for key, value in instances.items():
