@@ -8,23 +8,27 @@ import github
 
 class GithubAuthentication:
     """
-    Represents a token manager for authentication via GitHubApp.
+    Represents a token manager for authentication via GitHub App.
     """
 
     def get_token(self, namespace: str, repo: str) -> str:
         """
-        Returns GitHub token for a requested repository.
+        Get a GitHub token for requested repository.
 
-        :param namespace: namespace of the repository
-        :param repo: name of the repository
-        :return: token that can be used in PyGithub instance for authentication
+        Args:
+            namespace: Namespace of the repository.
+            repo: Name of the repository.
+
+        Returns:
+            A token that can be used in PyGithub instance for authentication.
         """
         raise NotImplementedError()
 
     @property
     def pygithub_instance(self) -> "github.Github":
         """
-        Returns generic PyGithub instance. Used for `GitUser` for example.
+        Returns:
+            Generic PyGithub instance. Used for `GitUser` for example.
         """
         raise NotImplementedError()
 
@@ -32,6 +36,9 @@ class GithubAuthentication:
     def try_create(**kwargs) -> Optional["GithubAuthentication"]:
         """
         Tries to construct authentication object from provided keyword arguments.
-        :return: None if unsuccessful
+
+        Returns:
+            `GithubAuthentication` object or `None` if the creation was not
+            successful.
         """
         raise NotImplementedError()
