@@ -1,24 +1,6 @@
-# MIT License
-#
-# Copyright (c) 2018-2019 Red Hat, Inc.
+# Copyright Contributors to the Packit project.
+# SPDX-License-Identifier: MIT
 
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
 import logging
 from typing import Optional, List
 
@@ -119,13 +101,16 @@ class GitlabService(BaseGitService):
         if namespace:
             try:
                 group = self.gitlab_instance.groups.get(namespace)
-            except gitlab.GitlabGetError:
-                raise GitlabAPIException(f"Group {namespace} not found.")
+            except gitlab.GitlabGetError as ex:
+                raise GitlabAPIException(f"Group {namespace} not found.") from ex
             data["namespace_id"] = group.id
 
         if description:
             data["description"] = description
-        new_project = self.gitlab_instance.projects.create(data)
+        try:
+            new_project = self.gitlab_instance.projects.create(data)
+        except gitlab.GitlabCreateError as ex:
+            raise GitlabAPIException("Project already exists") from ex
         return GitlabProject(
             repo=repo, namespace=namespace, service=self, gitlab_repo=new_project
         )
@@ -166,7 +151,6 @@ class GitlabService(BaseGitService):
             GitlabProject(
                 repo=project.attributes["path"],
                 namespace=project.attributes["namespace"]["full_path"],
-                gitlab_repo=project,
                 service=self,
             )
             for project in projects_to_convert
