@@ -1,31 +1,18 @@
-# MIT License
-#
-# Copyright (c) 2018-2019 Red Hat, Inc.
-
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+# Copyright Contributors to the Packit project.
+# SPDX-License-Identifier: MIT
 
 import logging
 from typing import List, Optional, Union
 
 import requests
+import urllib3
 
-from ogr.exceptions import PagureAPIException, OgrException, OperationNotSupported
+from ogr.exceptions import (
+    PagureAPIException,
+    OgrException,
+    OperationNotSupported,
+    OgrNetworkError,
+)
 from ogr.factory import use_for_service
 from ogr.parsing import parse_git_repo
 from ogr.services.base import BaseGitService, GitProject
@@ -38,8 +25,11 @@ logger = logging.getLogger(__name__)
 
 @use_for_service("pagure")
 @use_for_service("src.fedoraproject.org")
-@use_for_service("git.stg.centos.org")
+@use_for_service("src.stg.fedoraproject.org")
+@use_for_service("pkgs.fedoraproject.org")
+@use_for_service("pkgs.stg.fedoraproject.org")
 @use_for_service("git.centos.org")
+@use_for_service("git.stg.centos.org")
 class PagureService(BaseGitService):
     def __init__(
         self,
@@ -47,7 +37,7 @@ class PagureService(BaseGitService):
         instance_url: str = "https://src.fedoraproject.org",
         read_only: bool = False,
         insecure: bool = False,
-        max_retries: Union[int, requests.packages.urllib3.util.Retry] = 5,
+        max_retries: Union[int, urllib3.util.Retry] = 5,
         **kwargs,
     ) -> None:
         super().__init__()
@@ -110,6 +100,9 @@ class PagureService(BaseGitService):
 
     def get_project_from_url(self, url: str) -> "PagureProject":
         repo_url = parse_git_repo(potential_url=url)
+        if not repo_url:
+            raise OgrException(f"Cannot parse project url: '{url}'")
+
         if not repo_url.is_fork:
             repo_url.username = None
 
@@ -128,9 +121,20 @@ class PagureService(BaseGitService):
     def call_api(
         self, url: str, method: str = None, params: dict = None, data=None
     ) -> dict:
-        """Method used to call the API.
-        It returns the raw JSON returned by the API or raises an exception
-        if something goes wrong.
+        """
+        Call API endpoint.
+
+        Args:
+            url: URL to be called.
+            method: Method of the HTTP request, e.g. `"GET"`, `"POST"`, etc.
+            params: HTTP(S) query parameters in form of a dictionary.
+            data: Data to be sent in form of a dictionary.
+
+        Returns:
+            Dictionary representing response.
+
+        Raises:
+            PagureAPIException, if error occurs.
         """
         response = self.call_api_raw(url=url, method=method, params=params, data=data)
 
@@ -143,11 +147,14 @@ class PagureService(BaseGitService):
             raise PagureAPIException(
                 f"Page '{url}' not found when calling Pagure API.",
                 pagure_error=error_msg,
+                response_code=response.status_code,
             )
 
         if not response.json_content:
             logger.debug(response.content)
-            raise PagureAPIException("Error while decoding JSON: {0}")
+            raise PagureAPIException(
+                "Error while decoding JSON: {0}", response_code=response.status_code
+            )
 
         if not response.ok:
             logger.error(response.json_content)
@@ -161,14 +168,32 @@ class PagureService(BaseGitService):
                     msg,
                     pagure_error=error_msg,
                     pagure_response=response.json_content,
+                    response_code=response.status_code,
                 )
-            raise PagureAPIException(f"Problem with Pagure API when calling '{url}'")
+            raise PagureAPIException(
+                f"Problem with Pagure API when calling '{url}'",
+                response_code=response.status_code,
+            )
 
         return response.json_content
 
     def call_api_raw(
         self, url: str, method: str = None, params: dict = None, data=None
     ):
+        """
+        Call API endpoint and returns raw response.
+
+        Args:
+            url: URL to be called.
+            method: Method of the HTTP request, e.g. `"GET"`, `"POST"`, etc.
+            params: HTTP(S) query parameters in form of a dictionary.
+            data: Data to be sent in form of a dictionary.
+
+        Returns:
+            `RequestResponse` object that represents the response from the API
+            endpoint.
+        """
+
         method = method or "GET"
         try:
             response = self.get_raw_request(
@@ -177,12 +202,30 @@ class PagureService(BaseGitService):
 
         except requests.exceptions.ConnectionError as er:
             logger.error(er)
-            raise PagureAPIException(f"Cannot connect to url: '{url}'.", er)
+            raise OgrNetworkError(f"Cannot connect to url: '{url}'.") from er
         return response
 
     def get_raw_request(
         self, url, method="GET", params=None, data=None, header=None
     ) -> RequestResponse:
+        """
+        Call API endpoint and wrap the response in `RequestResponse` type.
+
+        Args:
+            url: URL to be called.
+            method: Method of the HTTP request, e.g. `"GET"`, `"POST"`, etc.
+
+                Defaults to `"GET"`.
+            params: HTTP(S) query parameters in form of a dictionary.
+            data: Data to be sent in form of a dictionary.
+            header: Header of the HTTP request.
+
+        Returns:
+            `RequestResponse` object representing the response.
+
+        Raises:
+            ValueError, if JSON cannot be retrieved.
+        """
 
         response = self.session.request(
             method=method,
@@ -209,15 +252,21 @@ class PagureService(BaseGitService):
 
     @property
     def api_url(self):
+        """URL to the Pagure API."""
         return f"{self.instance_url}/api/0/"
 
-    def get_api_url(self, *args, add_api_endpoint_part=True) -> str:
+    def get_api_url(self, *args, add_api_endpoint_part: bool = True) -> str:
         """
         Get a URL from its parts.
 
-        :param args: str parts of the url (e.g. "a", "b" will call "/a/b")
-        :param add_api_endpoint_part: Add part with API endpoint "/api/0/", True by default
-        :return: str
+        Args:
+            *args: String parts of the URL, e.g. `"a", "b"` will call `project/a/b`
+            add_api_endpoint_part: Add part with API endpoint (`/api/0/`).
+
+                Defaults to `True`.
+
+        Returns:
+            String
         """
         args_list: List[str] = []
 
@@ -229,8 +278,8 @@ class PagureService(BaseGitService):
 
     def get_api_version(self) -> str:
         """
-        Get Pagure API version.
-        :return:
+        Returns:
+            Version of the Pagure API.
         """
         request_url = self.get_api_url("version")
         return_value = self.call_api(request_url)
@@ -238,8 +287,8 @@ class PagureService(BaseGitService):
 
     def get_error_codes(self):
         """
-        Get a dictionary of all error codes.
-        :return:
+        Returns:
+            Dictionary with all error codes.
         """
         request_url = self.get_api_url("error_codes")
         return_value = self.call_api(request_url)
@@ -261,8 +310,8 @@ class PagureService(BaseGitService):
 
             try:
                 self.call_api(request_url, data={"projects": False})
-            except PagureAPIException:
-                raise OgrException(f"Namespace doesn't exist ({namespace}).")
+            except PagureAPIException as ex:
+                raise OgrException(f"Namespace doesn't exist ({namespace}).") from ex
 
             raise OgrException(
                 "Cannot create project in given namespace (permissions)."
