@@ -223,6 +223,25 @@ class GenericCommands(GithubTests):
         assert status
         assert len(status.comment) == 140
 
+    def test_commit_comment(self):
+        comment = self.hello_world_project.commit_comment(
+            commit="95069d7bedb6ae02def3fccce22169b412d08eac",
+            body="Testing commit comment",
+            filename="README.md",
+            row=6,
+        )
+        assert comment.sha == "95069d7bedb6ae02def3fccce22169b412d08eac"
+        assert comment.comment == "Testing commit comment"
+        assert comment.author == self.service.user.get_username()
+
+    def test_get_commit_comments(self):
+        comments = self.hello_world_project.get_commit_comments(
+            "95069d7bedb6ae02def3fccce22169b412d08eac"
+        )
+        assert len(comments)
+        assert comments[0].sha == "95069d7bedb6ae02def3fccce22169b412d08eac"
+        assert comments[0].comment == "Testing commit comment"
+
     def test_get_web_url(self):
         url = self.ogr_project.get_web_url()
         assert url == "https://github.com/packit/ogr"
