@@ -1,9 +1,16 @@
+# Copyright Contributors to the Packit project.
+# SPDX-License-Identifier: MIT
+
 import pytest
 from requre.online_replacing import record_requests_for_all_methods
 
 from tests.integration.github.base import GithubTests
 from ogr.abstract import IssueStatus
-from ogr.exceptions import GithubAPIException, OperationNotSupported
+from ogr.exceptions import (
+    GithubAPIException,
+    IssueTrackerDisabled,
+    OperationNotSupported,
+)
 
 
 @record_requests_for_all_methods()
@@ -12,9 +19,8 @@ class Issues(GithubTests):
     description = "This is a description"
 
     def test_issue_list(self):
-        issue_list = self.ogr_fork.get_issue_list()
-        assert isinstance(issue_list, list)
-        assert not issue_list
+        with self.assertRaises(IssueTrackerDisabled):
+            issue_list = self.ogr_fork.get_issue_list()
 
         issue_list_all = self.ogr_project.get_issue_list(status=IssueStatus.all)
         assert issue_list_all
@@ -126,6 +132,12 @@ class Issues(GithubTests):
         assert len(assignees) == 1
         assert assignees[0].login == "KPostOffice"
 
+    def test_issue_no_such_assignee(self):
+        project = self.service.get_project(repo="ogr", namespace="KPostOffice")
+        issue = project.get_issue(4)
+        with pytest.raises(GithubAPIException):
+            issue.add_assignee("slkdfjglkslfslkabcd")
+
     def test_list_contains_only_issues(self):
         issue_list_all = self.ogr_project.get_issue_list(status=IssueStatus.all)
         issue_ids = [issue.id for issue in issue_list_all]
@@ -134,6 +146,10 @@ class Issues(GithubTests):
         for id in pr_ids:
             assert id not in issue_ids
 
+    def test_issue_not_exists(self):
+        with pytest.raises(GithubAPIException):
+            self.ogr_project.get_issue(10**20)
+
     def test_functions_fail_for_pr(self):
         with pytest.raises(GithubAPIException):
             self.ogr_project.get_issue(1)
@@ -171,3 +187,13 @@ class Issues(GithubTests):
 
         issue.description = old_description
         assert issue.description == old_description
+
+    def test_get_comment(self):
+        comment = self.hello_world_project.get_issue(297).get_comment(926035728)
+        assert comment.body == "this is a comment"
+
+    def test_create_with_disabled_issues(self):
+        with self.assertRaises(IssueTrackerDisabled):
+            self.hello_world_project.get_fork().create_issue(
+                "Testing issue", "shouldn't be created"
+            )
