@@ -1,7 +1,13 @@
+# Copyright Contributors to the Packit project.
+# SPDX-License-Identifier: MIT
+
+import pytest
 from github import GithubException, UnknownObjectException
 from requre.online_replacing import record_requests_for_all_methods
 
 from tests.integration.github.base import GithubTests
+from ogr.exceptions import GithubAPIException
+from ogr.services.github.pull_request import GithubPullRequest
 
 
 @record_requests_for_all_methods()
@@ -80,6 +86,22 @@ class Service(GithubTests):
         )
         assert project.github_repo
 
+    def test_project_create_duplicate(self):
+        """
+        Remove the following project before data regeneration:
+        https://github.com/$USERNAME/repo_created_for_test_fail
+        """
+        name_of_the_repo = "repo_created_for_test_fail"
+        project = self.service.get_project(
+            repo=name_of_the_repo, namespace=self.service.user.get_username()
+        )
+        with self.assertRaises(GithubException):
+            project.github_repo
+
+        self.service.project_create(name_of_the_repo)
+        with pytest.raises(GithubAPIException):
+            self.service.project_create(name_of_the_repo)
+
     def test_list_projects_with_user_input(self):
         user = "packit"
         projects = self.service.list_projects(user=user)
@@ -92,3 +114,12 @@ class Service(GithubTests):
         projects = self.service.list_projects(user=user, language=language)
         assert len(projects) == 15
         assert {p.namespace for p in projects} == {"packit"}
+
+    def test_wrong_auth(self):
+        with pytest.raises(GithubAPIException):
+            self.service.project_create("test")
+
+    def test_wrong_auth_static_method(self):
+        # Verify that the exception handler is applied to static methods
+        with pytest.raises(GithubAPIException):
+            GithubPullRequest.get(self.ogr_project, 1)
