@@ -1,4 +1,8 @@
+# Copyright Contributors to the Packit project.
+# SPDX-License-Identifier: MIT
+
 from requre.online_replacing import record_requests_for_all_methods
+from ogr.exceptions import IssueTrackerDisabled
 
 from tests.integration.gitlab.base import GitlabTests
 from ogr.abstract import IssueStatus
@@ -216,3 +220,14 @@ class Issues(GitlabTests):
 
         issue.description = old_description
         assert issue.description == old_description
+
+    def test_get_comment(self):
+        comment = self.project.get_issue(102).get_comment(686264162)
+        assert comment.body == "issue comment"
+
+    def test_create_with_disabled_issues(self):
+        project = self.service.get_project(
+            namespace="packit-service", repo="private-testing-repo"
+        )
+        with self.assertRaises(IssueTrackerDisabled):
+            project.create_issue("Testing issue", "shouldn't be created")
